.. :changelog:

Changelog
---------

0.2.0 (2018-05-17)
++++++++++++++++

* Handle poor html values in links (`#5 <https://github.com/scottwernervt/favicon/issues/5>`_)
* Use given website for icon url scheme (`#6 <https://github.com/scottwernervt/favicon/issues/6>`_)

0.1.0 (2018-05-07)
++++++++++++++++

* First release.